@@ -6,19 +6,21 @@
 #'
 #' @return list of matrices containing median `C_ss` values.
 #' @export
-#' 
+#'
 #' @examples
 #' get_fixed_obesity(simulated_css = geo_tox_data$simulated_css,
 #'                   obesity = list(c("Obese", "Normal", "Obese"),
 #'                                  c("Normal", "Normal")))
 get_fixed_obesity <- function(simulated_css, obesity) {
-  
+
   if (!is.list(obesity)) obesity <- list(obesity)
-  
+
   lapply(obesity, function(x) {
-    do.call(cbind, lapply(simulated_css, function(df) {
+    out <- do.call(cbind, lapply(simulated_css, function(df) {
       df <- df |> dplyr::distinct(.data$weight, .data$weight_median_css)
       df$weight_median_css[match(x, df$weight)]
     }))
+    out <- out[, sort(colnames(out)), drop = FALSE]
+    out
   })
 }
